local common = require("mer.QuickLoadouts.common")


local function registerMod()
    EasyMCM = require("easyMCM.EasyMCM")

    local numLoadouts = common.numLoadouts


    local template = EasyMCM.createTemplate("Equipement rapide")

    for i = 1, numLoadouts do
        local loadoutID = "Ensemble " .. i
        local path = "loadouts." .. loadoutID
        local defaultKey =  "numpad" .. i
        local defaultKeyCode = tes3.scanCode[defaultKey]

        local pageName = "Ensemble " .. i
        local page = template:createSideBarPage({ label = pageName })

        --sidebar
        local sidebar = page.sidebar:createActiveInfo{
            variable = EasyMCM.createPlayerData{
                id = "loadoutInfo",
                path = path,
            },
        }
        common.sidebar = sidebar

        --Settings
        local cSettings = page:createCategory("Configuration de l'ensemble")
        cSettings:createTextField{
            label = "Nom de l'ensemble : ",
            variable = EasyMCM.createPlayerData{
                id = "name",
                path=path,
                defaultSetting = loadoutID
            },
            callback = function(self)
                tes3.messageBox("Nouveau nom de l'ensemble : \"%s\"", self.variable.value)
                common.updateInfo()
            end
        }

        cSettings:createOnOffButton{
            label = "Activer l'ensemble",
            variable = EasyMCM.createPlayerData{
                id = "enableLoadout",
                path=path,
                defaultSetting = false
            }
        }
        cSettings:createKeyBinder{
            label = "Touche pour quiper l'ensemble",
            allowCombinations = true,
            variable = EasyMCM.createPlayerData{
                id="hotkey",
                path=path,
                defaultSetting = { keyCode = defaultKeyCode}
            },
            getLetter = function(self, keyCode)
                for letter, code in pairs(tes3.scanCode) do
                    if code == keyCode then
                        return string.upper(letter)
                    end
                end
                return nil
            end
        }
        cSettings:createKeyBinder{
            label = "Touche pour attribuer l'quipement actuel  l'ensemble",
            allowCombinations = true,
            variable = EasyMCM.createPlayerData{
                id="assignKey",
                path=path,
                defaultSetting = { keyCode = defaultKeyCode, isShiftDown = true }
            },
            getLetter = function(self, keyCode)
                for letter, code in pairs(tes3.scanCode) do
                    if code == keyCode then
                        return string.upper(letter)
                    end
                end
                return nil
            end,
        }
        cSettings:createButton{
            buttonText = "Appliquer l'quipement actuel  l'ensemble",
            id = loadoutID,
            inGameOnly = true,
            callback = common.assignLoadout
        }

        --Weapons
        local cWeapons = page:createSideBySideBlock("Armes")
        cWeapons:createYesNoButton{
            label = "Inclure",
            description = "Inclut les armes dans cet ensemble.",
            variable = EasyMCM.createPlayerData{
                id = "includeWeapons",
                path = path,
                defaultSetting = true
            }
        }
        cWeapons:createYesNoButton{
            label = "Forcer le dsquipement",
            description = "Si cette option est active, tous les emplacements (mme vides) de cet ensemble forceront le dsquipement de l'quipement actuellement port.",
            variable = EasyMCM.createPlayerData{
                id = "unequipWeapons",
                path = path,
                defaultSetting = true
            }
        }

        --Shield
        local cShield = page:createSideBySideBlock("Boucliers")
        cShield:createYesNoButton{
            label = "Inclure",
            description = "Inclut les boucliers dans cet ensemble.",
            variable = EasyMCM.createPlayerData{
                id = "includeShield",
                path = path,
                defaultSetting = true
            }
        }
        cShield:createYesNoButton{
            label = "Forcer le dsquipement",
            description = "Si cette option est active, tous les emplacements (mme vides) de cet ensemble forceront le dsquipement de l'quipement actuellement port.",
            variable = EasyMCM.createPlayerData{
                id = "unequipShield",
                path = path,
                defaultSetting = true
            }
        }
        --Armor
        local cArmor = page:createSideBySideBlock("Armures")
        cArmor:createYesNoButton{
            label = "Inclure",
            description = "Inclut les armures dans cet ensemble.",
            variable = EasyMCM.createPlayerData{
                id = "includeArmor",
                path = path,
                defaultSetting = true
            }
        }
        cArmor:createYesNoButton{
            label = "Forcer le dsquipement",
            description = "Si cette option est active, tous les emplacements (mme vides) de cet ensemble forceront le dsquipement de l'quipement actuellement port.",
            variable = EasyMCM.createPlayerData{
                id = "unequipArmor",
                path = path,
                defaultSetting = true
            }
        }

        --Clothing
        local cClothing = page:createSideBySideBlock("Vtements")
        cClothing:createYesNoButton{
            label = "Inclure",
            description = "Inclut les vtements dans cet ensemble.",
            variable = EasyMCM.createPlayerData{
                id = "includeClothing",
                path = path,
                defaultSetting = true
            }
        }
        cClothing:createYesNoButton{
            label = "Forcer le dsquipement",
            description = "Si cette option est active, tous les emplacements (mme vides) de cet ensemble forceront le dsquipement de l'quipement actuellement port.",
            variable = EasyMCM.createPlayerData{
                id = "unequipClothing",
                path = path,
                defaultSetting = true
            }
        }
        --Accessories
        local cAccessories = page:createSideBySideBlock("Accessoires")
        cAccessories:createYesNoButton{
            label = "Inclure",
            description = "Inclut les accessoires (ceinture, anneaux, amulettes) dans cet ensemble.",
            variable = EasyMCM.createPlayerData{
                id = "includeAccessories",
                path = path,
                defaultSetting = true
            }
        }
        cAccessories:createYesNoButton{
            label = "Forcer le dsquipement",
            description = "Si cette option est active, tous les emplacements (mme vides) de cet ensemble forceront le dsquipement de l'quipement actuellement port.",
            variable = EasyMCM.createPlayerData{
                id = "unequipAccessories",
                path = path,
                defaultSetting = true
            }
        }
    end


    template:register()
end

event.register("modConfigReady", registerMod)
